@@ -5,7 +5,7 @@ require 5.005;  # 4-arg substr
 use strict;
 use vars qw($VERSION);
 
-$VERSION = "6.04";
+$VERSION = "6.05";
 
 my $CRLF = "\015\012";   # "\r\n" is not portable
 
@@ -259,7 +259,7 @@ sub my_readline {
                 die "read timeout" unless $self->can_read;
                 my $n = $self->sysread($_, 1024, length);
                 unless (defined $n) {
-                    redo READ if $!{EINTR};
+                    redo READ if $!{EINTR} || $!{EAGAIN};
                     # if we have already accumulated some data let's at least
                     # return that as a line
                     die "$what read failed: $!" unless length;
